@@ -29,12 +29,12 @@ import logging
 import os
 import random
 import signal
-import six
 import sys
 import time
 
 import eventlet
 from eventlet import event
+from eventlet import tpool
 
 from oslo_concurrency import lockutils
 from oslo_service._i18n import _
@@ -90,8 +90,7 @@ def _check_service_base(service):
                         % {'service': service, 'base': ServiceBase})
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ServiceBase(object):
+class ServiceBase(metaclass=abc.ABCMeta):
     """Base class for all services."""
 
     @abc.abstractmethod
@@ -126,8 +125,7 @@ class Singleton(type):
         return cls._instances[cls]
 
 
-@six.add_metaclass(Singleton)
-class SignalHandler(object):
+class SignalHandler(metaclass=Singleton):
 
     def __init__(self, *args, **kwargs):
         super(SignalHandler, self).__init__(*args, **kwargs)
@@ -200,12 +198,11 @@ class SignalHandler(object):
     def __setup_signal_interruption(self):
         """Set up to do the Right Thing with signals during poll() and sleep().
 
-        For Python 3.5 and later, deal with the changes in PEP 475 that prevent
-        a signal from interrupting eventlet's call to poll() or sleep().
+        Deal with the changes introduced in PEP 475 that prevent a signal from
+        interrupting eventlet's call to poll() or sleep().
         """
         select_module = eventlet.patcher.original('select')
-        self.__force_interrupt_on_signal = (sys.version_info >= (3, 5) and
-                                            hasattr(select_module, 'poll'))
+        self.__force_interrupt_on_signal = hasattr(select_module, 'poll')
 
         if self.__force_interrupt_on_signal:
             try:
@@ -564,6 +561,9 @@ class ProcessLauncher(object):
 
         pid = os.fork()
         if pid == 0:
+            # When parent used native threads the library on child needs to be
+            # "reset", otherwise native threads won't work on the child.
+            tpool.killall()
             self.launcher = self._child_process(wrap.service)
             while True:
                 self._child_process_handle_signal()
@@ -829,7 +829,7 @@ def launch(conf, service, workers=1, restart_method='reload'):
     :returns: instance of a launcher that was used to launch the service
     """
 
-    if workers is not None and not isinstance(workers, six.integer_types):
+    if workers is not None and not isinstance(workers, int):
         raise TypeError(_("Type of workers should be int!"))
 
     if workers is not None and workers <= 0:
