@@ -125,6 +125,12 @@ class Server(service.ServiceBase):
 
 def run(port_queue, workers=3, process_time=0):
     eventlet.patcher.monkey_patch()
+    # Monkey patch the original current_thread to use the up-to-date _active
+    # global variable. See https://bugs.launchpad.net/bugs/1863021 and
+    # https://github.com/eventlet/eventlet/issues/592
+    import __original_module_threading as orig_threading  # noqa
+    import threading  # noqa
+    orig_threading.current_thread.__globals__['_active'] = threading._active
 
     def hi_app(environ, start_response):
         # Some requests need to take time to process so the connection
